pg.ddx.io  pgsql-hackers@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Andreas Joseph Krogh <andreas@visena.com>
To: Andres Freund <andres@anarazel.de>
Cc: Robert Haas <robertmhaas@gmail.com>
Cc: Alvaro Herrera <alvherre@2ndquadrant.com>
Cc: Jonathan S. Katz <jkatz@postgresql.org>
Cc: PostgreSQL Hackers <pgsql-hackers@lists.postgresql.org>
Subject: Sv: Re: Query is over 2x slower with jit=on
Date: Wed, 22 Aug 2018 19:51:12 +0200 (CEST)
Message-ID: <VisenaEmail.28.47f1027d389da54b.16562b9da65@tc7-visena> (raw)
In-Reply-To: <20180822165155.tjbib4pewnbiyy4x@alap3.anarazel.de>

På onsdag 22. august 2018 kl. 18:51:55, skrev Andres Freund <andres@anarazel.de 
<mailto:andres@anarazel.de>>:
On 2018-08-22 18:39:18 +0200, Andreas Joseph Krogh wrote:
 > Just to be clear; The query really runs slower (wall-clock time), it's not
 > just the timing.

 I bet it's not actually running slower, it "just" takes longer to start
 up due to the JITing in each worker. I suspect what we should do is to
 multiple the cost limits by the number of workers, to model that.  But
 without the fixed instrumentation that's harder to see...
 
Well, yes, that might be. By "runs" I meant from me hitting ENTER in psql to 
the time the query finishes...
 
I thought JITing of prepared queries happended once (in "prepare") so it 
didn't have to do the JITing every time the query is executed. Isn't 
the previously generated bytecode usable for subsequent queries?
 
--
 Andreas Joseph Krogh

view thread (4+ messages)  latest in thread

Message-ID: <VisenaEmail.28.47f1027d389da54b.16562b9da65@tc7-visena>
Permalink:  ../VisenaEmail.28.47f1027d389da54b.16562b9da65@tc7-visena/
Also on:    postgresql.org/message-id/VisenaEmail.28.47f1027d389da54b.16562b9da65@tc7-visena

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-hackers@postgresql.org
  Cc: andreas@visena.com, andres@anarazel.de, robertmhaas@gmail.com, alvherre@2ndquadrant.com, jkatz@postgresql.org, pgsql-hackers@lists.postgresql.org
  Subject: Re: Sv: Re: Query is over 2x slower with jit=on
  In-Reply-To: <VisenaEmail.28.47f1027d389da54b.16562b9da65@tc7-visena>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox